//
//  NImageView.m
//  Created by Rodrigo on 8/10/11.
//  https://github.com/rigoneri/ObjC-NImageView
//  
//  Copyright (c) 2011, Rodrigo Neri <@rigoneri>
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//  
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//  
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//

#import "NImageView.h"

@interface NImageView (hidden)
- (void)showDefaultImage;
@end

@implementation NImageView

- (id)initWithFrame:(CGRect)frame andURL:(NSString *)url {
    if ((self = [super initWithFrame:frame])) {
        if (url && url.length > 0) {
            NURLConnection *connection = [[[NURLConnection alloc] init] autorelease];
            connection.delegate = self;
            [connection getFromCacheOrURL:url skipCache:NO];
            showDefaultImage = TRUE;
        }
        else {
            [self showDefaultImage];
        }
    }
    return self;
}

- (void)setImageFromUrl:(NSString *)url {
    if (url && url.length > 0) {
        NURLConnection *connection = [[[NURLConnection alloc] init] autorelease];
        connection.delegate = self;
        [connection getFromCacheOrURL:url skipCache:NO];
    }
    else {
        [self showDefaultImage];
    }
}

- (void)requestDidFail:(id)theConnection withError:(NSError *)error {
    [self showDefaultImage];
}

- (void)requestDidFinish:(id)theConnection {
    NURLConnection *conn = (NURLConnection *)theConnection;
    if (conn.receivedData) {
        [self setImage:[UIImage imageWithData:conn.receivedData]];
    }
    else {
        [self showDefaultImage];
    }
}

- (void)setShowDefaultImage:(BOOL)flag {
	showDefaultImage = flag;
}

- (void)showDefaultImage {
	if (showDefaultImage) {
		[self setImage:[UIImage imageNamed:@"default-image"]];
	}
}

- (void)dealloc {
    [super dealloc];
}

@end
