//
//  NURLConnection.h
//  Created by Rodrigo on 5/4/10.
//  https://github.com/rigoneri/ObjC-NURLConnection
//  
//  Copyright (c) 2011, Rodrigo Neri <@rigoneri>
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//  
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//  
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
//

#import <Foundation/Foundation.h>
#import <CommonCrypto/CommonDigest.h>

@protocol NURLConnectionDelegate <NSObject>
- (void)requestDidFinish:(id)connection;
@optional
- (void)requestDidFail:(id)connection withError:(NSError *)error;
@end

@interface NURLConnection : NSObject {
    id<NURLConnectionDelegate> delegate;
    NSMutableData *receivedData;
    NSURLConnection *connection;
    int status;
	
    NSString *cachePath;	
    NSString *filePath;
    NSData *previousCachedData;
    BOOL isCachedGetRequest;
    BOOL isGetRequestWithCache;
}

@property (nonatomic, assign) id delegate;
@property (nonatomic, retain) NSMutableData *receivedData;
@property (nonatomic, retain) NSData *previousCachedData;
@property (nonatomic, copy) NSString *cachePath;
@property (nonatomic, copy) NSString *filePath;

- (void)postToURL:(NSString *)url withBody:(NSString *)body;
- (void)postToURL:(NSString *)url withBody:(NSString *)body andToken:(NSString *)token;
- (void)getFromURL:(NSString *)url;
- (void)getFromURL:(NSString *)url andToken:(NSString *)token;
- (void)getFromURL:(NSString *)url ifModifiedSince:(NSDate *)date;
- (void)getFromCacheOrURL:(NSString *)url skipCache:(BOOL)skipCache;
- (int)status;

@end

